// Title:   Deletor.cpp
// Created: Thu Sep 25 15:16:47 2003
// Authors: Simon Heinzle, Tim Weyrich
//
// Copyright (c) 2001, 2002, 2003, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#include "Deletor.h"

#ifdef _WIN32
	// turn off std::map warnings
	//# pragma warning(push)
	# pragma warning(disable:4786) 
#endif

#include <qapplication.h>

#include "../../../../Core/DataStructures/src/SurfelCollection.h"
#include "../../../../Core/Interfaces/src/SurfelInterface.h"
#include "../../../../Core/Scene/src/Object.h"
#include "../../../../Core/Scene/src/Scene.h"

#include "ScanToolsGlobals.h"

#include "NewOverload.h"

Deletor::Deletor() : NormalAction() {
	_name = "point deletion";
	_selection_index = 0;
}

void Deletor::execute() {
	QApplication::setOverrideCursor(Qt::waitCursor);

	// if no selection set do nothing
	if (_selection_index<0 || _selection_index>3) {
		QApplication::restoreOverrideCursor();	
		return ;
	}
	
	Scene *scene = Scene::getInstance();
	
	Selector::getInstance()->invalidateSurfels(Selector::intToFlag(_selection_index));
	scene->removeSurfels(Selector::intToFlag(_selection_index), true);

	QApplication::restoreOverrideCursor();		
}

UndoAction* Deletor::executeUndo() {
	DeleteUndo *undo;

	QApplication::setOverrideCursor(Qt::waitCursor);

	std::vector<SurfelInterface*> selected_surfels;
	std::map<unsigned int, Object*> object_indices;
	
	// if no selection set do nothing
	if (_selection_index<0 || _selection_index>3) {
		QApplication::restoreOverrideCursor();	
		return 0;
	}
	
	Scene *scene = Scene::getInstance();
	Selector::getInstance()->getSelectionSurfelsAndIndexObject(Selector::intToFlag(_selection_index), selected_surfels, object_indices);

	undo = new DeleteUndo(selected_surfels, object_indices);
	_MCnew( (unsigned long)undo, sizeof(DeleteUndo(selected_surfels, object_indices)), __FILE__, __LINE__);
	
	Selector::getInstance()->invalidateSurfels(Selector::intToFlag(_selection_index));
	scene->removeSurfels(Selector::intToFlag(_selection_index), true);
	
	QApplication::restoreOverrideCursor();		
	return undo;
}




// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
