// Title:   ScanToolsConfigurationDialogImpl.cpp
// Created: Thu Sep 25 15:15:38 2003
// Authors: Simon Heinzle, Tim Weyrich
//
// Copyright (c) 2001, 2002, 2003, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#include <qlineedit.h>
#include <qcheckbox.h>
#include <qfiledialog.h>
#include <qcombobox.h>
#include <qspinbox.h>
#include <qlabel.h>
#include <qradiobutton.h>
#include <qpushbutton.h>
#if QT_VERSION >= 0x030000
# include <qptrlist.h>
# ifndef QList
#  define QList QPtrList
# endif
# ifndef QListIterator
#  define QListIterator QPtrListIterator
# endif
#else
# include <qlist.h>
#endif
#include <qstring.h>
#include <qfile.h>
#include <qbuttongroup.h>
#include <qstringlist.h>
#include <qcolordialog.h>
#include <qslider.h>
#include <qapplication.h>

#if QT_VERSION >= 0x030000
# include <qptrvector.h>
# ifndef QVector
#  define QVector QPtrVector
# endif
# ifndef QVectorIterator
#  define QVectorIterator QPtrVectorIterator
# endif
#else
# include <qvector.h>
#endif

#include "../../../../DataTypes/src/Vector3D.h"
#include "../../../../Utilities/src/Matrix.h"
#include "../../../../Core/Scene/src/Scene.h"

#include "../UI/ScanToolsConfigurationWidget.h"
#include "ScanToolsConfigurationDialogImpl.h"

#include "NewOverload.h"

// ########################################
// singleton pattern, the singleton itself
// ########################################
static ScanToolsConfigurationDialogImpl *instance;
	

// #####################################
//  c'tor & d'tor (private / protected)
// #####################################

ScanToolsConfigurationDialogImpl::ScanToolsConfigurationDialogImpl (QWidget* parent, const char* name, WFlags flags) 
		: ScanToolsConfigurationWidget(parent, name, flags)
{
}

ScanToolsConfigurationDialogImpl::~ScanToolsConfigurationDialogImpl(void)
{
}

// ####################################
//  public methods
// ####################################

ScanToolsConfigurationDialogImpl *ScanToolsConfigurationDialogImpl::getInstance(void) {
	if (instance == 0) {
		instance = new ScanToolsConfigurationDialogImpl ();
		_MCnew( (unsigned long)instance, sizeof(instance), __FILE__, __LINE__);
	}
	return instance;
}

void ScanToolsConfigurationDialogImpl::destroyInstance(void) {
	if (instance) {
		instance->close();
		_MCdelete((unsigned int)instance);
		delete instance;
	}
	instance = 0;
}

void ScanToolsConfigurationDialogImpl::initDialog(void) {

}


void ScanToolsConfigurationDialogImpl::setStandardMessage() {
	this->ErrorLabel->setText("Scan Cleaning tools didn't succeed in completing the task. This could be due to wrong usage of the tool set, wrong programming of the tool set or due to unknown interstellar forces that influenced this pc so heavily that it doesn't do what it should do.");
}

void ScanToolsConfigurationDialogImpl::setWrongArgumentsMessage() {
	this->ErrorLabel->setText("One of the arguments could not be converted to a number. Check your argument boxes again - perhaps a whitespace at the end of a number or a wrong character occurs in an edit box.");
}

void ScanToolsConfigurationDialogImpl::setBorderMessage() {
	this->ErrorLabel->setText("You need to select a border for the local particle simulation!");
}

void ScanToolsConfigurationDialogImpl::setAreaMessage() {
	this->ErrorLabel->setText("You need to select an area in which no false normals occur first!");
}



// ####################################
//  public slots
// ####################################




void ScanToolsConfigurationDialogImpl::passMousePress(QMouseEvent *me) { 
} 

void ScanToolsConfigurationDialogImpl::passMouseRelease(QMouseEvent *me){ 
}

void ScanToolsConfigurationDialogImpl::passMouseMove(QMouseEvent *me) { 

}

void ScanToolsConfigurationDialogImpl::keyPressEvent(QKeyEvent *ke) {
	ke->ignore();
}

void ScanToolsConfigurationDialogImpl::keyReleaseEvent(QKeyEvent *ke) {
	ke->ignore();
}

void ScanToolsConfigurationDialogImpl::passKeyPressEvent(QKeyEvent   *ke) {
	ke->ignore();
}

void ScanToolsConfigurationDialogImpl::passKeyReleaseEvent(QKeyEvent   *ke) {
	ke->ignore();
	
}

void ScanToolsConfigurationDialogImpl::setQCursor(QCursor *new_cursor) {
	
}







// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
