// Title:   Selection.cpp
// Created: Thu Sep 25 15:15:25 2003
// Authors: Simon Heinzle, Tim Weyrich
//
// Copyright (c) 2001, 2002, 2003, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#include "Selection.h"

Selection::Selection(SurfelInterface::Flag flag, int selection_count,Object *current_object) {
	_selector = Selector::getInstance();
	_selected_surfels = 0;
	_selection_count = selection_count;
	_flag = flag;
	_iteration_active = false;
	_from_object = current_object;
}


Selection::~Selection() {
	if (_selected_surfels)
		delete _selected_surfels;
	// unmark surfels
	_selection_tool->setActiveSelection(0);
	_selection_tool->clearSelection();
	_selection_tool->setActiveSelection(1);
	_selection_tool->clearSelection();
	_selection_tool->setActiveSelection(2);
	_selection_tool->clearSelection();
}

int Selection::getNOfSurfels(void) {
	return _selection_count;
}

bool Selection::isIterationActive(void) {
	return _iteration_active;
}

SurfelInterface* Selection::operator[](int index) {
	if (_selected_surfels == 0)
		buildSelectionArray();
	return _selector->_all_surfels[_selected_surfels[index]];
}
/*
Vector3D& Selection::operator()(int index) {
	return _selector->_all_positions[_selected_surfels[index]];
}
*/
SurfelInterface* Selection::getFirstSurfel() {
	_iteration_active = true;

	_current_iteration_index = 0;
	if ((_selector->_valid_surfels[_current_iteration_index])&&(_selector->_all_surfels[_current_iteration_index]->isFlagOn(_flag)))
		return _selector->_all_surfels[_current_iteration_index];
	else
		return getNextSurfel();

}

SurfelInterface* Selection::getNextSurfel() {
	while (_current_iteration_index < _selector->_all_surfels_count-1) {
		_current_iteration_index++;
		if ((_selector->_valid_surfels[_current_iteration_index])&&(_selector->_all_surfels[_current_iteration_index]->isFlagOn(_flag)))
			return _selector->_all_surfels[_current_iteration_index];
	}
	// no surfel found!
	return 0;
}

void Selection::buildSelectionArray(void) {
	int new_count = 0;

	_selected_surfels = new int[_selection_count];
	for (unsigned int i=0; i<_selector->_all_surfels_count; i++) {
		if ((_selector->_valid_surfels[i])&&(_selector->_all_surfels[i]->isFlagOn(_flag))) {
			_selected_surfels[new_count] = i;
			new_count++;
		}
	}

	_selection_count = new_count;
}


// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
