// Title:   SurfelResizer.h
// Created: Thu Sep 25 15:14:57 2003
// Authors: Simon Heinzle, Tim Weyrich
//
// Copyright (c) 2001, 2002, 2003, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __SURFELRESIZER_H
#define __SURFELRESIZER_H

#include "Action.h"

class SurfelResizer : public NormalAction {
	float _length;
	float _diameter;
	float _scale;

	bool _retain_scale;

	Vector3D _bb_lower_corner;
	Vector3D _bb_upper_corner;
	Vector3D _bb_center;
	Vector3D _center_of_gravity;


	void analyse();
	void resize();
	void translateAndScale();
	
public:

	// Important note:
	// user has to adjust scene view (translation, rotation, scale) 
	// resulting translation is scaled same as object
	// resulting scene scale is scaled inverse to object

	SurfelResizer();
	void setLength(float len) { _length = len; };
	void setKeepScale(bool keep_scale) { _retain_scale = keep_scale; }
	void execute();
	UndoAction *executeUndo();
};

class SurfelResizerUndo : public UndoAction {
	float _scale;
	Vector3D _translation;
public:
	SurfelResizerUndo(float scale, const Vector3D& translation); 
	UndoAction *undo();
};


#endif
// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
